as.arrows: Add directional arrows from a SpatRaster to a plot
Description
Create directional arrows and add these to a plot, typically used to represent vector fields such as wind directions, drainage flow directions, or other angular data.
SpatRaster with values representing angles or directions
unit
Character. Unit of the angle values in x. One of "degrees", "radians" or "flowdir". See terrain for flowdir
arrow_length
Numeric. Length of the arrows to be plotted
clockwise
Logical. Default is FALSE. If TRUE, angles measured in radians or degrees are considered clockwise
angle_from_x_axis
Anti-clockwise angle from x (or horizontal) axis to the reference direction
angle_from_h_axis
Anti-clockwise angle from x (or horizontal) axis to the reference direction. In the case of northing wind direction it is often used angle_from_x_axis=90, unit="deg", clockwise=TRUE