Evaluate whether two SpatRasters have the same extent, number of rows and columns, projection, resolution, and origin (or a subset of these comparisons).
Or evaluate whether two SpatVectors have the same geometries, or whether a SpatVector has duplicated geometries.
# S4 method for SpatRaster,SpatRaster
compareGeom(x, y, ..., lyrs=FALSE, crs=TRUE, warncrs=FALSE, ext=TRUE,
rowcol=TRUE, res=FALSE, stopOnError=TRUE, messages=FALSE, tolerance=NULL)# S4 method for SpatVector,SpatVector
compareGeom(x, y, tolerance=0)
# S4 method for SpatVector,missing
compareGeom(x, y, tolerance=0)
logical (SpatRaster) or matrix of logical (SpatVector)
SpatRaster or SpatVector
Same as x. If x is a SpatRaster, y can also be a list of SpatRasters. If x is a SpatVector, y can be missing
Additional SpatRasters
logical. If TRUE, the number of layers is compared
logical. If TRUE, coordinate reference systems are compared
logical. If TRUE, a warning is given if the crs is different (instead of an error)
logical. If TRUE, bounding boxes are compared
logical. If TRUE, number of rows and columns of the objects are compared
logical. If TRUE, resolutions are compared (redundant when checking extent and rowcol)
logical. If TRUE, code execution stops if raster do not match
logical. If TRUE, warning/error messages are printed even if stopOnError=FALSE
numeric. For SpatRaster objects this is the difference in raster extent (expressed as the fraction of the raster resolution) that can be ignored when comparing alignment of rasters. If NULL the value shown by link{terraOptions} is used
r1 <- rast()
r2 <- rast()
r3 <- rast()
compareGeom(r1, r2, r3)
nrow(r3) <- 10
if (FALSE) {
compareGeom(r1, r3)
}
Run the code above in your browser using DataLab