| gdal | R Documentation |
Set the GDAL warning level or get a data.frame with the available GDAL drivers (file formats), or, if warn=NA and drivers=FALSE, you get the version numbers of one or all of the GDAL, PROJ and GEOS libraries.
GDAL is the software library that terra builds on to read and write spatial data and for some raster data processing. PROJ is used for transformation of coordinates ("projection") and GEOS is used for geometric operations with vector data.
The current GDAL configuration options are obtained with getGDALconfig and changed with setGDALconfig.
proj_ok checks if the PROJ database with CRS definitions can be found.
projNetwork controls whether PROJ can access network resources for coordinate transformations. By default, network access is enabled to provide high-accuracy grid-based datum transformations where available. When disabled, PROJ falls back to "ballpark transformations" (of unknown accuracy) which could lead to errors of hundreds of meters in some cases. When enabled, PROJ downloads transformation grids from https://cdn.proj.org, requiring network connectivity and valid SSL certificates. After a successful run, the files are cached locally.
projPaths gets or sets the search paths that PROJ uses to find coordinate system definitions and transformation grids. This allows users to specify custom locations for PROJ data files, such as when using offline installations or custom grid files. By default, it operates on PROJ search paths, but can also set GDAL search paths when with_proj=FALSE.
gdal(warn=NA, drivers=FALSE, ...)
gdalCache(size=NA)
setGDALconfig(option, value="")
getGDALconfig(option)
clearVSIcache()
libVersion(lib="all", parse=FALSE)
unloadGDALdrivers(x)
proj_ok()
projNetwork(enable, url="")
projPaths(paths, with_proj = TRUE)
warn |
If |
drivers |
logical. If |
... |
additional arguments (for backwards compatibility only) |
size |
numeric. The new cache size in MB |
option |
character. GDAL configuration option name, or a "name=value" string (in which case the value argument is ignored |
value |
character. value for GDAL configuration option. Use "" to reset it to its default value |
lib |
character. "gdal", "proj", "geos", "TBB", or any other value to get the versions numbers of the first three and a logical value indicating whether TBB paralellization is available |
parse |
logical. Should the version be parsed into three numerical values (major, minor and sub versions)? |
x |
character. Drivers names such as "GTiff" to be unloaded. Or "" to reload all drivers |
enable |
logical. If |
url |
character. Optional URL for PROJ network endpoint. If empty string (default), uses PROJ's default network settings ( |
paths |
character. Vector of file paths to directories containing PROJ data files. If missing, returns the current search paths |
with_proj |
logical. If |
character vector in most cases.
While some spatial analyses may not be greatly affected by PROJ network settings (ballpark vs. grid-based transformations), the differences can be significant, especially when a transformation involves a shift in datum between different coordinate reference systems. For applications requiring high positional accuracy, ensure network access is enabled or grids are locally available. Grids can be pre-downloaded using the projsync utility or installed via system packages, such as proj-data on Ubuntu/Debian systems. Downloaded grids are cached locally and then reused for subsequent transformations.
On Windows, PROJ network access may fail with SSL certificate errors (e.g. "schannel: CertGetCertificateChain trust error"). If you see these warnings during project operations, you can use projNetwork(FALSE) to disable network access and silence them. To fix the underlying SSL issue, ensure your system's certificate store is up to date, or install the required PROJ datum grids locally.
describe for file-level metadata "GDALinfo"
gdal()
gdal(2)
#head(gdal(drivers=TRUE))
libVersion("all", TRUE)
projNetwork()
projPaths()
projPaths(c("/custom/proj/path"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.