| proj_pipelines | R Documentation |
Find candidate coordinate transformation pipelines between two coordinate reference systems. This can be used to examine which transformations are available, whether they require grid files, and what accuracy they provide. You can use a selected pipeline with the project methods
proj_pipelines(from, to, authority="", AOI=NULL, use="NONE",
grid_availability="USED", desired_accuracy=-1.0, strict_containment=FALSE)
from |
character, SpatRaster, SpatVector, or any object from which |
to |
same types as for |
authority |
character. Constrain output pipelines to those from this authority (e.g. |
AOI |
SpatExtent. Area of interest for the transformation in degrees. For an area of interest crossing the anti-meridian, west should be greater than east, e.g. |
use |
character. One of |
grid_availability |
character. One of |
desired_accuracy |
numeric. Only return pipelines with at least this accuracy (in metres). Use |
strict_containment |
logical. If |
A data.frame with "pipelines" and the following columns:
human-readable description
PROJ pipeline definition string
logical; whether the pipeline has an inverse
accuracy in metres; -1 indicates unknown (ballpark) accuracy
number of grids required by this pipeline
logical; whether the pipeline can be used (all required grids are available)
Requires PROJ >= 7.1 (inc" 3). See projNetwork to enable online grid downloading.
crs, project, same.crs, projNetwork
## Not run:
# Simple case: WGS84 to UTM zone 32N
proj_pipelines("EPSG:4326", "EPSG:32632")
# Many pipelines between NAD83/Conus Albers and WGS84
pp <- proj_pipelines("EPSG:5070", "EPSG:4326")
nrow(pp)
# Only pipelines that work without downloading grids
pp_local <- proj_pipelines("EPSG:5070", "EPSG:4326", grid_availability="DISCARD")
pp_local
# Using a SpatRaster as input
r <- rast(ncols=10, nrows=10, crs="EPSG:4326")
proj_pipelines(r, "EPSG:3857")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.