Description
Zoom in on a map (plot) by providing a new extent, by default this is done by clicking twice on the map.
Usage
# S4 method for SpatRaster
zoom(x, ext=draw(), maxcell=10000, layer=1, new=TRUE, ...)
Arguments
maxcell
Maximum number of cells used for the map
layer
Positive integer to select the layer to be used
new
Logical. If TRUE, the zoomed in map will appear on a new device (window)
...
additional paramters for plot
Value
SpatExtent (invisibly)