| NAflag | R Documentation |
The main purpose of this method is to allow correct reading of a SpatRaster that is based on a file that has an incorrect or missing NA flag. The file is not changed, but the flagged value is set to NA when values are read from the file. In contrast, if the cell values are in memory the change is made immediately. NAflag does *not* return the "NoData Value" that is stored in the file (use describe to find that value.
To change cell values, you can use classify
## S4 method for signature 'SpatRaster'
NAflag(x)
## S4 replacement method for signature 'SpatRaster'
NAflag(x)<-value
x |
SpatRaster |
value |
numeric. The value to be interpreted as NA; set this before reading the values from the file. This can be a single value, or multiple values, one for each data source (file / subdataset) |
none or numeric
classify
s <- rast(system.file("ex/logo.tif", package="terra"))[[1]]
NAflag(s) <- 255
plot(s)
NAflag(s)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.