Learn R Programming

terra (version 1.9-11)

NAflag: Set the NA flag

Description

The main purpose of this method is to allow correct reading of a SpatRaster that is based on a file that has an incorrect or missing NA flag. The file is not changed, but the flagged value is set to NA when values are read from the file. In contrast, if the cell values are in memory the change is made immediately.

To change cell values, you can use classify

Usage

# S4 method for SpatRaster
NAflag(x)

# S4 method for SpatRaster NAflag(x)<-value

Value

none or numeric

Arguments

x

SpatRaster

value

numeric. The value to be interpreted as NA; set this before reading the values from the file. This can be a single value, or multiple values, one for each data source (file / subdataset)

See Also

classify

Examples

Run this code
s <- rast(system.file("ex/logo.tif", package="terra"))[[1]]   
NAflag(s) <- 255
plot(s)
NAflag(s)

Run the code above in your browser using DataLab