powered by
Adaptation of grid that allows adding a grid to a map. This function will place the grid in the locations within the mapped area as delineated by the axes.
grid
If you set the tick marks yourself, you can use add_abline to create a grid:
add_abline
Also see graticule
graticule
add_grid(nx=NULL, ny=nx, col="lightgray", lty="dotted", lwd=1)
graticule, add_abline, add_legend, add_box, add_grid, add_mtext
add_legend
add_box
add_grid
add_mtext
v <- vect(system.file("ex/lux.shp", package="terra")) plot(v) add_grid()
Run the code above in your browser using DataLab