- from
character, SpatRaster, SpatVector, or any object from which crs() can extract a CRS
- to
same types as for from
- authority
character. Constrain output pipelines to those from this authority (e.g. "EPSG"). Default "" means no constraint
- AOI
SpatExtent. Area of interest for the transformation in degrees. For an area of interest crossing the anti-meridian, west should be greater than east, e.g. ext(150, 210, 0, 30)
- use
character. One of "NONE", "BOTH", "INTERSECTION", "SMALLEST", indicating how areas of interest of source and target CRS are used. Ignored when AOI is specified
- grid_availability
character. One of "USED" (grid availability is used for sorting; operations with missing grids are sorted last), "DISCARD" (discard operations if a required grid is missing), "IGNORED" (ignore grid availability; results presented as if all grids were available), or "AVAILABLE" (results presented as if grids known to PROJ were available; typical when networking is enabled)
- desired_accuracy
numeric. Only return pipelines with at least this accuracy (in metres). Use -1 (the default) to impose no accuracy constraint
- strict_containment
logical. If FALSE (the default), permit partial matching of the area of interest. If TRUE, the area of interest must be strictly contained