Methods to create a SpatRasterDataset. This is an object to hold "sub-datasets", each represented by a SpatRaster that may have multiple layers. All sub-datasets must have the same raster geometry (extent and resolution). You can use a SpatRasterCollection (see sprc) to combine SpatRasters with different geometries.
See describe for getting information about the sub-datasets present in a file.
# S4 method for missing
sds(x) # S4 method for character
sds(x, ids=0, opts=NULL, raw=FALSE, noflip=FALSE, guessCRS=TRUE, domains="", md=FALSE)
# S4 method for SpatRaster
sds(x, ...)
# S4 method for list
sds(x)
# S4 method for array
sds(x, crs="", extent=NULL)
SpatRasterDataset
character (filename), or SpatRaster, or list of SpatRasters, or missing. If multiple filenames are provided, it is attempted to make SpatRasters from these, and combine them into a SpatRasterDataset
optional. vector of integer subdataset ids. Ignored if the first value is not a positive integer
character. GDAL dataset open options
logical. If TRUE, scale and offset values are ignored
logical. If TRUE, a raster (e.g. JPEG image) that is not georeferenced and that GDAL assigns a flipped extent to (ymax < ymin), is not considered flipped. This avoids the need to flip the raster vertically
logical. If TRUE and the file does not specify a CRS but has an extent that is within longitude/latitude bounds, the longitude/latitude crs is assigned to the SpatRaster
character. Metadata domains to read (see metags to retrieve their values if there are any). "" is the default domain
logical. If TRUE, the multi-dimensional GDAL API is used for reading the file. This API can only be used for a few file formats (netCDF/HDF5) and can sometimes provide notably faster reading of data with many (time) steps in the third or higher dimension. If no subdataset is selected with subds, all usable arrays are combined into one SpatRaster (like md=FALSE); a warning reports how many variables and layers were combined when there is more than one variable.
character. Description of the Coordinate Reference System (map projection) in PROJ.4, WKT or authority:code notation. If this argument is missing, and the x coordinates are within -360 .. 360 and the y coordinates are within -90 .. 90, longitude/latitude is assigned
SpatExtent
additional SpatRaster objects
sprc, describe
s <- rast(system.file("ex/logo.tif", package="terra"))
x <- sds(s, s/2)
names(x) <- c("first", "second")
x
length(x)
# extract the second SpatRaster
x[2]
a <- array(1:9, c(3,3,3,3))
sds(a)
Run the code above in your browser using DataLab