Subset geometries by minimum distance
thin.Rdthin return a subset of geometries such that all remaining geometries are at least d apart from each other. This uses greedy spatial thinning: the first geometry is always kept, and subsequent geometries are only kept if they are at least d away from all previously kept geometries.
thinNodes reduces the number of nodes to represent line or polygon geometries
Usage
# S4 method for class 'SpatVector'
thin(x, d, unit="m")
# S4 method for class 'SpatVector'
thinNodes(x, d, unit="m", makeValid=TRUE)